@@ -23,13 +23,13 @@ var defaultColors = []string{
 	"#8858AA",
 }
 
-// Dot struct
+// Dot struct.
 type Dot struct {
 	config *config.Config
 	tmpl   embed.FS
 }
 
-// New return Dot
+// New return Dot.
 func New(c *config.Config) *Dot {
 	return &Dot{
 		config: c,
@@ -93,7 +93,7 @@ func (d *Dot) OutputViewpoint(wr io.Writer, v *schema.Viewpoint) error {
 	groups := []map[string]interface{}{}
 	nogroup := v.Schema.Tables
 	for i, g := range v.Groups {
-		tables, _, err := v.Schema.SepareteTablesThatAreIncludedOrNot(&schema.FilterOption{
+		tables, _, err := v.Schema.SeparateTablesThatAreIncludedOrNot(&schema.FilterOption{
 			Include:       g.Tables,
 			IncludeLabels: g.Labels,
 		})
@@ -139,13 +139,12 @@ func (d *Dot) schemaTemplate() (string, error) {
 			return "", errors.WithStack(err)
 		}
 		return string(tb), nil
-	} else {
-		tb, err := d.tmpl.ReadFile("templates/schema.dot.tmpl")
-		if err != nil {
-			return "", errors.WithStack(err)
-		}
-		return string(tb), nil
 	}
+	tb, err := d.tmpl.ReadFile("templates/schema.dot.tmpl")
+	if err != nil {
+		return "", errors.WithStack(err)
+	}
+	return string(tb), nil
 }
 
 func (d *Dot) tableTemplate() (string, error) {
@@ -155,11 +154,10 @@ func (d *Dot) tableTemplate() (string, error) {
 			return "", errors.WithStack(err)
 		}
 		return string(tb), nil
-	} else {
-		tb, err := d.tmpl.ReadFile("templates/table.dot.tmpl")
-		if err != nil {
-			return "", errors.WithStack(err)
-		}
-		return string(tb), nil
 	}
+	tb, err := d.tmpl.ReadFile("templates/table.dot.tmpl")
+	if err != nil {
+		return "", errors.WithStack(err)
+	}
+	return string(tb), nil
 }
