@@ -21,13 +21,13 @@ import (
 	"golang.org/x/image/font/sfnt"
 )
 
-// Gviz struct
+// Gviz struct.
 type Gviz struct {
 	config *config.Config
 	dot    *dot.Dot
 }
 
-// New return Gviz
+// New return Gviz.
 func New(c *config.Config) *Gviz {
 	return &Gviz{
 		config: c,
@@ -35,7 +35,7 @@ func New(c *config.Config) *Gviz {
 	}
 }
 
-// OutputSchema generage image for full relation.
+// OutputSchema generate image for full relation.
 func (g *Gviz) OutputSchema(wr io.Writer, s *schema.Schema) error {
 	buf := &bytes.Buffer{}
 	if err := g.dot.OutputSchema(buf, s); err != nil {
@@ -44,7 +44,7 @@ func (g *Gviz) OutputSchema(wr io.Writer, s *schema.Schema) error {
 	return g.render(wr, buf.Bytes())
 }
 
-// OutputTable generage image for table.
+// OutputTable generate image for table.
 func (g *Gviz) OutputTable(wr io.Writer, t *schema.Table) error {
 	buf := &bytes.Buffer{}
 	if err := g.dot.OutputTable(buf, t); err != nil {
@@ -53,7 +53,7 @@ func (g *Gviz) OutputTable(wr io.Writer, t *schema.Table) error {
 	return g.render(wr, buf.Bytes())
 }
 
-// OutputViewpoint generage image for viewpoint.
+// OutputViewpoint generate image for viewpoint.
 func (g *Gviz) OutputViewpoint(wr io.Writer, v *schema.Viewpoint) error {
 	buf := &bytes.Buffer{}
 	if err := g.dot.OutputViewpoint(buf, v); err != nil {
@@ -74,7 +74,7 @@ func (g *Gviz) render(wr io.Writer, b []byte) (e error) {
 			return errors.WithStack(err)
 		}
 		// FIXME: more better way
-		graphviz.SetFontLoader(func(ctx context.Context, job *graphviz.Job, font *graphviz.TextFont) (font.Face, error) {
+		graphviz.SetFontLoader(func(_ context.Context, _ *graphviz.Job, font *graphviz.TextFont) (font.Face, error) {
 			return faceFunc(font.Size())
 		})
 	}
@@ -156,7 +156,7 @@ func Output(s *schema.Schema, c *config.Config, force bool) (e error) {
 	return nil
 }
 
-// getFaceFunc
+// getFaceFunc.
 func getFaceFunc(keyword string) (func(size float64) (font.Face, error), error) {
 	var (
 		faceFunc func(size float64) (font.Face, error)
