@@ -8,10 +8,10 @@ import (
 type Cardinality string
 
 const (
-	ZeroOrOne          Cardinality = "Zero or one"
-	ExactlyOne         Cardinality = "Exactly one"
-	ZeroOrMore         Cardinality = "Zero or more"
-	OneOrMore          Cardinality = "One or more"
+	ZeroOrOne          Cardinality = "zero_or_one"
+	ExactlyOne         Cardinality = "exactly_one"
+	ZeroOrMore         Cardinality = "zero_or_more"
+	OneOrMore          Cardinality = "one_or_more"
 	UnknownCardinality Cardinality = ""
 )
 
@@ -23,6 +23,13 @@ var cardinalityAliases = map[string]Cardinality{
 	"one or zero":  ZeroOrOne,
 	"zero or many": ZeroOrMore,
 	"one or many":  OneOrMore,
+	"zero_or_one":  ZeroOrOne,
+	"exactly_one":  ExactlyOne,
+	"zero_or_more": ZeroOrMore,
+	"one_or_more":  OneOrMore,
+	"one_or_zero":  ZeroOrOne,
+	"zero_or_many": ZeroOrMore,
+	"one_or_many":  OneOrMore,
 	"many(0)":      ZeroOrMore,
 	"many(1)":      OneOrMore,
 	"0+":           ZeroOrMore,
